import { generateActivityType, generatePriceType } from '@/common/goods.helper.js'
import { fetchProductDetail } from '@/services/api/goods.js'
import { fetchCouponListByProductId } from '@/services/api/coupon.js'

const goodsDetail = {
    methods: {
        // 获取商品详情
        async fetchProductDetail(productId) {
            try {
                const userId = this.$store.getters.userId
                const res = await fetchProductDetail({ productId, userId })
                return this.generateProductInfo(res.data)
            } catch (e) {
                return e
            }
        },

        // 处理商品信息
        generateProductInfo(product) {
            if (!product) return product
            // 商品活动类型
            product.activityType = generateActivityType(product)
            product.priceType = generatePriceType(product)
            product.skus = product.skus.map(sku => {
                sku.activityType = generateActivityType(sku)
                sku.priceType = generatePriceType(sku)
                return sku
            })
            return product
        },

        // 获取商品可用优惠券
        async fetchCouponListByProduct(productId) {
            try {
                const userId = this.$store.getters.userId
                const res = await fetchCouponListByProductId({ productId, userId })
                return res.data.map(coupon => this.generateCoupon(coupon))
            } catch (e) {
                return e
            }
        },

        // 创建优惠券
        generateCoupon(coupon) {
            const obj = Object.assign({}, coupon)
            // 添加标题
            if (coupon.noThresholdFlag > 0) {
                obj.couponTitle = `减￥${coupon.couponAmount}元`
            } else {
                obj.couponTitle = `满￥${coupon.touchPrice}元减￥${coupon.couponAmount}元`
            }
            // 添加优惠券状态
            if (obj.useStatus === 0) {
                obj.controlType = 'receive'
            } else if (obj.useStatus === 1) {
                obj.couponStatus = 'received'
                obj.controlType = 'search'
            }
            return obj
        },
    }
}


export default goodsDetail
